@@ -20,7 +20,6 @@
 * MA 02110-1301, USA.
 */
 
-#include "oxygenapplicationname.h"
 #include "oxygencairosurface.h"
 #include "oxygenhook.h"
 #include "oxygensignal.h"
@@ -30,10 +29,8 @@
 #include <vector>
 #include <map>
 
-#ifdef GDK_WINDOWING_X11
 #include <X11/Xdefs.h>
 #include <X11/Xlib.h>
-#endif
 
 namespace Oxygen
 {
@@ -56,10 +53,6 @@ namespace Oxygen
         //! initialize hooks
         void initializeHooks( void );
 
-        //! application name
-        void setApplicationName( const ApplicationName& applicationName )
-        { _applicationName = applicationName; }
-
         //! initialize
         void initialize( const ColorUtils::Rgba&, const WindowShadow& );
 
@@ -84,9 +77,7 @@ namespace Oxygen
         void createPixmapHandles( void );
 
         //! create Pixmap for given surface
-        #ifdef GDK_WINDOWING_X11
         Pixmap createPixmap( const Cairo::Surface&, int opacity = 255 ) const;
-        #endif
 
         //! install shadow X11 property on given widget
         /*!
@@ -115,13 +106,8 @@ namespace Oxygen
         //! shadow tileset
         TileSet _squareTiles;
 
-        //! application name
-        ApplicationName _applicationName;
-
-        #ifdef GDK_WINDOWING_X11
         //! shadow atom
         Atom _atom;
-        #endif
 
         //! number of pixmaps
         enum { numPixmaps = 8 };
